# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FeedTypes


class UpdateFeed(BaseModel):
    update_feed: Optional["UpdateFeedUpdateFeed"] = Field(alias="updateFeed")


class UpdateFeedUpdateFeed(BaseModel):
    id: str
    name: str
    state: EntityState
    type: FeedTypes


UpdateFeed.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetProduct(BaseModel):
    product: Optional["GetProductProduct"]


class GetProductProduct(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["GetProductProductAddress"]
    manufacturer: Optional[str]
    model: Optional[str]
    brand: Optional[str]
    upc: Optional[str]
    sku: Optional[str]
    release_date: Optional[Any] = Field(alias="releaseDate")
    production_date: Optional[Any] = Field(alias="productionDate")


class GetProductProductAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


GetProduct.model_rebuild()
GetProductProduct.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ObservableTypes,
    OccurrenceTypes,
)


class IngestMemory(BaseModel):
    ingest_memory: Optional["IngestMemoryIngestMemory"] = Field(alias="ingestMemory")


class IngestMemoryIngestMemory(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    collections: Optional[List[Optional["IngestMemoryIngestMemoryCollections"]]]
    observations: Optional[List[Optional["IngestMemoryIngestMemoryObservations"]]]


class IngestMemoryIngestMemoryCollections(BaseModel):
    id: str
    name: str


class IngestMemoryIngestMemoryObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "IngestMemoryIngestMemoryObservationsObservable"
    related: Optional["IngestMemoryIngestMemoryObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[
        List[Optional["IngestMemoryIngestMemoryObservationsOccurrences"]]
    ]
    state: EntityState


class IngestMemoryIngestMemoryObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class IngestMemoryIngestMemoryObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class IngestMemoryIngestMemoryObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional[
        "IngestMemoryIngestMemoryObservationsOccurrencesBoundingBox"
    ] = Field(alias="boundingBox")


class IngestMemoryIngestMemoryObservationsOccurrencesBoundingBox(BaseModel):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


IngestMemory.model_rebuild()
IngestMemoryIngestMemory.model_rebuild()
IngestMemoryIngestMemoryObservations.model_rebuild()
IngestMemoryIngestMemoryObservationsOccurrences.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryNotionPages(BaseModel):
    notion_pages: Optional["QueryNotionPagesNotionPages"] = Field(alias="notionPages")


class QueryNotionPagesNotionPages(BaseModel):
    results: Optional[List[str]]


QueryNotionPages.model_rebuild()
